ODFI Templates Package
===========================

- 1.0.4

    + Added support for Steps Record Files stored as ZipFiles, as it is the default save format of the windows tool

- 1.0.3

    + Fixed SVG group support
    + Added Support for Steps Record files from Windows Steps Recorder tool
